@@ -20,12 +20,13 @@ from bec_lib import (
     messages,
 )
 from bec_lib.connector import ConnectorBase
-from device_server.devices.config_update_handler import ConfigUpdateHandler
-from device_server.devices.device_serializer import get_device_info
 from ophyd.ophydobj import OphydObject
 from ophyd.signal import EpicsSignalBase
 from typeguard import typechecked
 
+from device_server.devices.config_update_handler import ConfigUpdateHandler
+from device_server.devices.device_serializer import get_device_info
+
 try:
     from bec_plugins import devices as plugin_devices
 except ImportError:
@@ -51,7 +52,7 @@ class DSDevice(DeviceBase):
         self.metadata = {}
         self.initialized = False
 
-    def initialize_device_buffer(self, producer):
+    def initialize_device_buffer(self, connector):
         """initialize the device read and readback buffer on redis with a new reading"""
         dev_msg = messages.DeviceMessage(signals=self.obj.read(), metadata={})
         dev_config_msg = messages.DeviceMessage(signals=self.obj.read_configuration(), metadata={})
@@ -62,14 +63,16 @@ class DSDevice(DeviceBase):
             }
         else:
             limits = None
-        pipe = producer.pipeline()
-        producer.set_and_publish(MessageEndpoints.device_readback(self.name), dev_msg, pipe=pipe)
-        producer.set(topic=MessageEndpoints.device_read(self.name), msg=dev_msg, pipe=pipe)
-        producer.set_and_publish(
+        pipe = connector.pipeline()
+        connector.set_and_publish(MessageEndpoints.device_readback(self.name), dev_msg, pipe=pipe)
+        connector.set_and_publish(
+            topic=MessageEndpoints.device_read(self.name), msg=dev_msg, pipe=pipe
+        )
+        connector.set_and_publish(
             MessageEndpoints.device_read_configuration(self.name), dev_config_msg, pipe=pipe
         )
         if limits is not None:
-            producer.set_and_publish(
+            connector.set_and_publish(
                 MessageEndpoints.device_limits(self.name),
                 messages.DeviceMessage(signals=limits),
                 pipe=pipe,
@@ -144,7 +147,7 @@ class DeviceManagerDS(DeviceManagerBase):
                 logger.info(f"Adding device {name}: {'ENABLED' if enabled else 'DISABLED'}")
                 try:
                     dev_cls = self._get_device_class(dev.get("deviceClass"))
-                    if issubclass(dev_cls, opd.DeviceProxy):
+                    if issubclass(dev_cls, (opd.DeviceProxy, opd.ComputedSignal)):
                         delayed_init.append(dev)
                         continue
                     self.initialize_device(dev)
@@ -175,8 +178,12 @@ class DeviceManagerDS(DeviceManagerBase):
         name = dev.get("name")
         enabled = dev.get("enabled")
         logger.info(f"Adding device {name}: {'ENABLED' if enabled else 'DISABLED'}")
-        self.initialize_device(dev)
+        obj = self.initialize_device(dev)
 
+        if hasattr(obj.obj, "lookup"):
+            self._register_device_proxy(name)
+
+    def _register_device_proxy(self, name: str) -> None:
         obj_lookup = self.devices.get(name).obj.lookup
         for key in obj_lookup.keys():
             signal_name = obj_lookup[key].get("signal_name")
@@ -191,9 +198,11 @@ class DeviceManagerDS(DeviceManagerBase):
                     f"Failed to init DeviceProxy {name}, no signal {signal_name} found for device {key}."
                 )
             if key not in registered_proxies:
+                # pylint: disable=protected-access
                 self.devices[key].obj._registered_proxies.update({name: signal_name})
                 continue
             if key in registered_proxies and signal_name not in registered_proxies[key]:
+                # pylint: disable=protected-access
                 self.devices[key].obj._registered_proxies.update({name: signal_name})
                 continue
             if key in registered_proxies.keys() and signal_name in registered_proxies[key]:
@@ -318,7 +327,7 @@ class DeviceManagerDS(DeviceManagerBase):
         self.update_config(obj, config)
 
         # refresh the device info
-        pipe = self.producer.pipeline()
+        pipe = self.connector.pipeline()
         self.reset_device_data(obj, pipe)
         self.publish_device_info(obj, pipe)
         pipe.execute()
@@ -369,7 +378,7 @@ class DeviceManagerDS(DeviceManagerBase):
     def initialize_enabled_device(self, opaas_obj):
         """connect to an enabled device and initialize the device buffer"""
         self.connect_device(opaas_obj.obj)
-        opaas_obj.initialize_device_buffer(self.producer)
+        opaas_obj.initialize_device_buffer(self.connector)
 
     @staticmethod
     def disconnect_device(obj):
@@ -420,7 +429,7 @@ class DeviceManagerDS(DeviceManagerBase):
         """
 
         interface = get_device_info(obj, {})
-        self.producer.set(
+        self.connector.set(
             MessageEndpoints.device_info(obj.name),
             messages.DeviceInfoMessage(device=obj.name, info=interface),
             pipe,
@@ -428,9 +437,9 @@ class DeviceManagerDS(DeviceManagerBase):
 
     def reset_device_data(self, obj: OphydObject, pipe=None) -> None:
         """delete all device data and device info"""
-        self.producer.delete(MessageEndpoints.device_status(obj.name), pipe)
-        self.producer.delete(MessageEndpoints.device_read(obj.name), pipe)
-        self.producer.delete(MessageEndpoints.device_info(obj.name), pipe)
+        self.connector.delete(MessageEndpoints.device_status(obj.name), pipe)
+        self.connector.delete(MessageEndpoints.device_read(obj.name), pipe)
+        self.connector.delete(MessageEndpoints.device_info(obj.name), pipe)
 
     def _obj_callback_readback(self, *_args, obj: OphydObject, **kwargs):
         if obj.connected:
@@ -438,8 +447,8 @@ class DeviceManagerDS(DeviceManagerBase):
             signals = obj.read()
             metadata = self.devices.get(obj.root.name).metadata
             dev_msg = messages.DeviceMessage(signals=signals, metadata=metadata)
-            pipe = self.producer.pipeline()
-            self.producer.set_and_publish(MessageEndpoints.device_readback(name), dev_msg, pipe)
+            pipe = self.connector.pipeline()
+            self.connector.set_and_publish(MessageEndpoints.device_readback(name), dev_msg, pipe)
             pipe.execute()
 
     @typechecked
@@ -466,7 +475,7 @@ class DeviceManagerDS(DeviceManagerBase):
             metadata = self.devices[name].metadata
             msg = messages.DeviceMonitorMessage(device=name, data=value, metadata=metadata)
             stream_msg = {"data": msg}
-            self.producer.xadd(
+            self.connector.xadd(
                 MessageEndpoints.device_monitor(name),
                 stream_msg,
                 max_size=min(100, int(max_size // dsize)),
@@ -476,7 +485,7 @@ class DeviceManagerDS(DeviceManagerBase):
         device = kwargs["obj"].root.name
         status = 0
         metadata = self.devices[device].metadata
-        self.producer.send(
+        self.connector.set(
             MessageEndpoints.device_status(device),
             messages.DeviceStatusMessage(device=device, status=status, metadata=metadata),
         )
@@ -489,8 +498,8 @@ class DeviceManagerDS(DeviceManagerBase):
         device = kwargs["obj"].root.name
         status = int(kwargs.get("value"))
         metadata = self.devices[device].metadata
-        self.producer.set(
-            MessageEndpoints.device_status(kwargs["obj"].root.name),
+        self.connector.set(
+            MessageEndpoints.device_status(device),
             messages.DeviceStatusMessage(device=device, status=status, metadata=metadata),
         )
 
@@ -521,12 +530,12 @@ class DeviceManagerDS(DeviceManagerBase):
                 )
             )
         ds_obj.emitted_points[metadata["scanID"]] = max_points
-        pipe = self.producer.pipeline()
-        self.producer.send(MessageEndpoints.device_read(obj.root.name), bundle, pipe=pipe)
+        pipe = self.connector.pipeline()
+        self.connector.send(MessageEndpoints.device_read(obj.root.name), bundle, pipe=pipe)
         msg = messages.DeviceStatusMessage(
             device=obj.root.name, status=max_points, metadata=metadata
         )
-        self.producer.set_and_publish(
+        self.connector.set_and_publish(
             MessageEndpoints.device_progress(obj.root.name), msg, pipe=pipe
         )
         pipe.execute()
@@ -536,4 +545,4 @@ class DeviceManagerDS(DeviceManagerBase):
         msg = messages.ProgressMessage(
             value=value, max_value=max_value, done=done, metadata=metadata
         )
-        self.producer.set_and_publish(MessageEndpoints.device_progress(obj.root.name), msg)
+        self.connector.set_and_publish(MessageEndpoints.device_progress(obj.root.name), msg)
